summaryrefslogtreecommitdiff
path: root/sw/inc/swtypes.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/swtypes.hxx')
-rw-r--r--sw/inc/swtypes.hxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/sw/inc/swtypes.hxx b/sw/inc/swtypes.hxx
index 0d37e63c367d..1f417052638d 100644
--- a/sw/inc/swtypes.hxx
+++ b/sw/inc/swtypes.hxx
@@ -116,15 +116,15 @@ enum SwLabelType
};
-const BYTE OLD_MAXLEVEL = 5;
-const BYTE MAXLEVEL = 10; //Ehemals numrule.hxx
-const BYTE NO_NUM = 200; //Ehemals numrule.hxx
-//const BYTE NO_NUMBERING = 201; //Ehemals numrule.hxx //#outline level,removed by zhaojianwei
-//const BYTE NO_INIT = 202; //Ehemals numrule.hxx
+const sal_uInt8 OLD_MAXLEVEL = 5;
+const sal_uInt8 MAXLEVEL = 10; //Ehemals numrule.hxx
+const sal_uInt8 NO_NUM = 200; //Ehemals numrule.hxx
+//const sal_uInt8 NO_NUMBERING = 201; //Ehemals numrule.hxx //#outline level,removed by zhaojianwei
+//const sal_uInt8 NO_INIT = 202; //Ehemals numrule.hxx
// fuer Absaetze mit NO_NUM aber auf unterschiedlichen Leveln
// DAMIT entfaellt das NO_NUM !!!!
-const BYTE NO_NUMLEVEL = 0x20; // wird mit den Levels verodert
+const sal_uInt8 NO_NUMLEVEL = 0x20; // wird mit den Levels verodert
/*
@@ -145,9 +145,9 @@ extern SwPathFinder *pPathFinder;
// multiplizieren; Ebenen 0..4 !!!)
// -> #i30312#
-const USHORT lBullIndent = 1440/4;
+const sal_uInt16 lBullIndent = 1440/4;
const short lBullFirstLineOffset = -lBullIndent;
-const USHORT lNumIndent = 1440/4;
+const sal_uInt16 lNumIndent = 1440/4;
const short lNumFirstLineOffset = -lNumIndent;
const short lOutlineMinTextDistance = 216; // 0.15 inch = 0.38 cm
// <- #i30312#
@@ -212,7 +212,7 @@ extern const sal_Char* __FAR_DATA pMarkToOLE;
#endif
-typedef USHORT SetAttrMode;
+typedef sal_uInt16 SetAttrMode;
namespace nsSetAttrMode
{
@@ -301,7 +301,7 @@ enum PrepareHint
PREP_FTN, //Fussnoten-Invalidierung
PREP_POS_CHGD, //Position des Frm hat sich verandert
//(Zum Fly-Umbruch pruefen). Im void* des Prepare()
//wird ein BOOL& uebergeben, dieser zeigt mit TRUE,
//dass ein Format ausgefuehrt wurde.
PREP_UL_SPACE, //UL-Space hat sich veraendert, TxtFrms muessen
//den Zeilenabstand neu kalkulieren.
@@ -301,7 +301,7 @@ enum PrepareHint
PREP_POS_CHGD, //Position des Frm hat sich verandert
//(Zum Fly-Umbruch pruefen). Im void* des Prepare()
- //wird ein BOOL& uebergeben, dieser zeigt mit TRUE,
+ //wird ein sal_Bool& uebergeben, dieser zeigt mit sal_True,
//dass ein Format ausgefuehrt wurde.
PREP_UL_SPACE, //UL-Space hat sich veraendert, TxtFrms muessen